.. SPDX-FileCopyrightText: 2021 geisserml <geisserml@gmail.com>
.. SPDX-License-Identifier: CC-BY-4.0

Command-line Interface
======================

PyPDFium2 also has a command-line interface:

.. program-output:: pypdfium2 --help
